Implementation
==============

Elastic is implemented as an extension module to 
`ASE <https://wiki.fysik.dtu.dk/ase/>`_ system

The Elastic package provides, basically, one main python module and one 
auxiliary module (:ref:`par-calc-mod`) which can be useful outside of 
the scope of the main code. The :ref:`par-calc-mod` is not distributed 
separately but can be just placed by itself somewhere in your python path
and used with any part of the ASE.
I hope it will be incorporated in the main project sometime in the future.

.. _modules:

Modules
-------

.. automodule:: parcalc.parcalc
   :members:

.. automodule:: elastic.elastic
   :members:


